.. _api_fileset:

DICOM File-sets (:mod:`pydicom.fileset`)
========================================

.. currentmodule:: pydicom.fileset

Representation of DICOM File-sets.

.. autosummary::
   :toctree: generated/

   RecordNode
   FileInstance
   FileSet
   generate_filename
   is_conformant_file_id
   DIRECTORY_RECORDERS
